==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/app/assets/javascripts/spirit_hub/controllers/base_form_controller.js <==
import { Controller } from '@hotwired/stimulus';

export default class extends Controller {
  static targets = ['submitButton', 'submitText', 'addAction', 'nextAction'];

  connect() {
    this.requiredFields = this.element.querySelectorAll('*[required]');
    this.originalSubmitTextContent = this.submitTextTarget.textContent

    if (this.hasAddActionTarget) {
      this.updateSubmitContentHandler = this.updateSubmitContent.bind(this);
      this.addActionTarget.addEventListener('change', this.updateSubmitContentHandler);
      this.nextActionTarget.addEventListener('valueChanged', this.updateSubmitContentHandler);
    }

    this.updateSubmitVisibilityHandler = this.updateSubmitVisibility.bind(this);
    this.requiredFields.forEach(el => {
      ['valueChanged', 'keyup', 'change'].forEach(eventType => {
        el.addEventListener(eventType, this.updateSubmitVisibilityHandler);
      });
    });

    this.updateSubmitVisibility();
  }

  disconnect() {
    if (this.hasAddActionTarget) {
      this.addActionTarget.removeEventListener('change', this.updateSubmitContentHandler);
      this.nextActionTarget.removeEventListener('valueChanged', this.updateSubmitContentHandler);
    }

    this.requiredFields.forEach(el => {
      ['valueChanged', 'keyup', 'change'].forEach(eventType => {
        el.removeEventListener(eventType, this.updateSubmitVisibilityHandler);
      });
    });
  }

  updateSubmitVisibility() {
    const shouldShowSubmit = this.calculateShouldShowSubmit();

    this.submitButtonTarget.classList.toggle('hidden', !shouldShowSubmit);
    this.submitButtonTarget.setAttribute('type', shouldShowSubmit ? 'submit' : 'button');
    this.updateSubmitContent();
  }

  calculateShouldShowSubmit() {
    const allFieldsFilled = Array.from(this.requiredFields).every(el => this.isNotEmptyField(el));
    const isAddActionValid = this.hasAddActionTarget && this.addActionTarget.checked ? !!this.nextActionTarget.value : true;
    return allFieldsFilled && isAddActionValid;
  }

  isNotEmptyField(el) {
    switch (el.type) {
      case 'checkbox':
      case 'radio':
        return el.checked;
      case 'file':
        return el.files.length > 0;
      default:
        return el.value.trim().length > 0;
    }
  }

  updateSubmitContent() {
    let text;

    if (this.hasAddActionTarget && this.addActionTarget.checked) {
      text = "Valider et passer à l'action suivante";
    } else {
      text = this.originalSubmitTextContent;
    }

    this.submitTextTarget.textContent = text;
  }
}

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/app/assets/javascripts/spirit_hub/controllers/base_form_controller.js <==
import { Controller } from '@hotwired/stimulus';

export default class extends Controller {
  static targets = ['submitButton', 'submitText', 'addAction', 'nextAction', 'fileInput'];

  connect() {
    this.requiredFields = this.element.querySelectorAll('*[required]');
    this.originalSubmitTextContent = this.submitTextTarget.textContent;

    if (this.hasAddActionTarget) {
      this.updateSubmitContentHandler = this.updateSubmitContent.bind(this);
      this.addActionTarget.addEventListener('change', this.updateSubmitContentHandler);
      this.nextActionTarget.addEventListener('valueChanged', this.updateSubmitContentHandler);
    }

    this.updateSubmitVisibilityHandler = this.updateSubmitVisibility.bind(this);
    this.requiredFields.forEach(el => {
      ['valueChanged', 'keyup', 'change'].forEach(eventType => {
        el.addEventListener(eventType, this.updateSubmitVisibilityHandler);
      });
    });

    if (this.hasFileInputTarget) {
      this.fileInputTarget.addEventListener('updatedFiles', this.fileInputChanged.bind(this));
    }

    this.updateSubmitVisibility();
  }

  disconnect() {
    if (this.hasAddActionTarget) {
      this.addActionTarget.removeEventListener('change', this.updateSubmitContentHandler);
      this.nextActionTarget.removeEventListener('valueChanged', this.updateSubmitContentHandler);
    }

    this.requiredFields.forEach(el => {
      ['valueChanged', 'keyup', 'change'].forEach(eventType => {
        el.removeEventListener(eventType, this.updateSubmitVisibilityHandler);
      });
    });

    if (this.hasFileInputTarget) {
      this.fileInputTarget.removeEventListener('updatedFiles', this.updateSubmitVisibilityHandler);
    }
  }

  fileInputChanged() {
    this.updateSubmitVisibility();
  }

  updateSubmitVisibility() {
    const shouldShowSubmit = this.calculateShouldShowSubmit();

    this.submitButtonTarget.classList.toggle('hidden', !shouldShowSubmit);
    this.submitButtonTarget.setAttribute('type', shouldShowSubmit ? 'submit' : 'button');
    this.updateSubmitContent();
  }

  calculateShouldShowSubmit() {
    const allFieldsFilled = Array.from(this.requiredFields).every(el => this.isNotEmptyField(el));
    const isAddActionValid = this.hasAddActionTarget && this.addActionTarget.checked ? !!this.nextActionTarget.value : true;
    return allFieldsFilled && isAddActionValid;
  }

  isNotEmptyField(el) {
    switch (el.type) {
      case 'checkbox':
      case 'radio':
        return el.checked;
      case 'file':
        return el.files.length > 0;
      default:
        return el.value.trim().length > 0;
    }
  }

  updateSubmitContent() {
    let text;

    if (this.hasAddActionTarget && this.addActionTarget.checked) {
      text = "Valider et passer à l'action suivante";
    } else {
      text = this.originalSubmitTextContent;
    }

    this.submitTextTarget.textContent = text;
  }
}
